==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QXmlStreamNotationDeclaration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qxmlstream.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlStreamNotationDeclaration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlStreamNotationDeclaration")
    QXmlStreamNotationDeclaration *_ptr = reinterpret_cast<QXmlStreamNotationDeclaration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlStreamNotationDeclaration()
void __qt_construct_QXmlStreamNotationDeclaration_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNotationDeclaration()")
    Q_UNUSED(__java_arguments)
    QXmlStreamNotationDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNotationDeclaration();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
void __qt_construct_QXmlStreamNotationDeclaration_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)")
    jobject arg__1 = __java_arguments[0].l;
    const QXmlStreamNotationDeclaration& __qt_arg__1 = qtjambi_cast<const QXmlStreamNotationDeclaration& >(__jni_env, arg__1);
    QXmlStreamNotationDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNotationDeclaration(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QXmlStreamNotationDeclaration
void __qt_destruct_QXmlStreamNotationDeclaration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlStreamNotationDeclaration")
    reinterpret_cast<QXmlStreamNotationDeclaration*>(ptr)->~QXmlStreamNotationDeclaration();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNotationDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNotationDeclaration_0, sizeof(QXmlStreamNotationDeclaration), typeid(QXmlStreamNotationDeclaration), false, &deleter_QXmlStreamNotationDeclaration, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNotationDeclaration_2Lio_qt_core_QXmlStreamNotationDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNotationDeclaration_1, sizeof(QXmlStreamNotationDeclaration), typeid(QXmlStreamNotationDeclaration), false, &deleter_QXmlStreamNotationDeclaration, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNotationDeclaration::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::name()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNotationDeclaration::operator=(QXmlStreamNotationDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_assign_1native_1cref_1QXmlStreamNotationDeclaration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::operator=(QXmlStreamNotationDeclaration)", __qt_this)
        const QXmlStreamNotationDeclaration& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamNotationDeclaration>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNotationDeclaration::operator==(QXmlStreamNotationDeclaration)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_operator_1equal_1native_1cref_1QXmlStreamNotationDeclaration_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::operator==(QXmlStreamNotationDeclaration)const", __qt_this)
        const QXmlStreamNotationDeclaration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamNotationDeclaration>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNotationDeclaration::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::publicId()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNotationDeclaration::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::systemId()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlStreamNotationDeclaration(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlStreamNotationDeclaration>("QXmlStreamNotationDeclaration", "io/qt/core/QXmlStreamNotationDeclaration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlStreamNotationDeclaration, {
        ConstructorInfo(&__qt_construct_QXmlStreamNotationDeclaration_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlStreamNotationDeclaration_1, "Lio/qt/core/QXmlStreamNotationDeclaration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlStreamNotationDeclaration);
    registerMetaType<QXmlStreamNotationDeclaration>("QXmlStreamNotationDeclaration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QXmlStreamNotationDeclaration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qxmlstream.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlStreamNotationDeclaration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlStreamNotationDeclaration")
    QXmlStreamNotationDeclaration *_ptr = reinterpret_cast<QXmlStreamNotationDeclaration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlStreamNotationDeclaration()
void __qt_construct_QXmlStreamNotationDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNotationDeclaration()")
    Q_UNUSED(__java_arguments)
    QXmlStreamNotationDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNotationDeclaration();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNotationDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNotationDeclaration, sizeof(QXmlStreamNotationDeclaration), typeid(QXmlStreamNotationDeclaration), 0, false, &deleter_QXmlStreamNotationDeclaration, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
void __qt_construct_QXmlStreamNotationDeclaration_cref_QXmlStreamNotationDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)")
    jobject other0 = __java_arguments[0].l;
    const QXmlStreamNotationDeclaration& __qt_other0 = qtjambi_cast<const QXmlStreamNotationDeclaration&>(__jni_env, other0);
    QXmlStreamNotationDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNotationDeclaration(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNotationDeclaration_2Lio_qt_core_QXmlStreamNotationDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNotationDeclaration_cref_QXmlStreamNotationDeclaration, sizeof(QXmlStreamNotationDeclaration), typeid(QXmlStreamNotationDeclaration), 0, false, &deleter_QXmlStreamNotationDeclaration, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QXmlStreamNotationDeclaration
void __qt_destruct_QXmlStreamNotationDeclaration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlStreamNotationDeclaration")
    reinterpret_cast<QXmlStreamNotationDeclaration*>(ptr)->~QXmlStreamNotationDeclaration();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlStreamNotationDeclaration::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::name()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNotationDeclaration::operator==(QXmlStreamNotationDeclaration)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_equals_1native_1cref_1QXmlStreamNotationDeclaration_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::operator==(QXmlStreamNotationDeclaration)const", __this_nativeId)
        const QXmlStreamNotationDeclaration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamNotationDeclaration>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNotationDeclaration::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::publicId()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNotationDeclaration::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNotationDeclaration::systemId()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNotationDeclaration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlStreamNotationDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNotationDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlStreamNotationDeclaration(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlStreamNotationDeclaration>("QXmlStreamNotationDeclaration", "io/qt/core/QXmlStreamNotationDeclaration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QXmlStreamNotationDeclaration, {
        ConstructorInfo(&__qt_construct_QXmlStreamNotationDeclaration, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlStreamNotationDeclaration_cref_QXmlStreamNotationDeclaration, "Lio/qt/core/QXmlStreamNotationDeclaration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlStreamNotationDeclaration);
    registerMetaType<QXmlStreamNotationDeclaration>("QXmlStreamNotationDeclaration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
